#!/bin/bash
# Program cpcdailyrain-sa.bash 
# Copyright (C) Assela Pathirana
# 
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
# #########################################################################
. CONSTANTS.bash
SKIP="" #skip/do the time consuming download/extract part (In bash false means "" REMEMBER!!)
PRESERVE="" # do/not erase the intermediate files

if [ $# -lt 1 ] ; then 
  echo "checks the CPC ftp site for precip data for "
  echo "  daily raihfall date,"
  echo "if exists, downloads the data and plots "
  echo "usage: $0 YYYMMDD (e.g. 20050519) format"
  echo "Dependancies: "
  echo "GMT tools "
  echo "imagemagick"
  echo "which will be sourced here to get most of the "
  echo "important parameters"
  echo "plot.inc"
  echo
  exit 
fi
err=0
if [ ! -f "plot.inc" ]; then 
  echo "plot.inc : file not found!"
  exit 5
fi
rm -f .gmt*  
#set -x
source './plot.inc'
hdiff=24 #this is 24h process
datares=0.1/0.1 # geographical resolution of data in degrees
datacorners=70/110/5/35 # extent of  data
outname=$STATICNAME.CPC.$1
databox=$datacorners
echo $databox

tmp=$0.tmp
#d2=`./date_shift 1 $d1`
#for date in $d1 $d2; do
date=$1
echo "doing $date.."
if [ ! "$SKIP" ]; then 
  wget -o $tmp.wget.out -O $outname.gz ftp://ftp.cpc.ncep.noaa.gov/fews/S.Asia/data/cpc_rfe_v2.0_sa_dly.bin.$date.gz 
err=$(( $err + $? )) 
  /usr/bin/gunzip -f $outname.gz
err=$(( $err + $? )) 
fi
if [ $err -gt 0 ]; then 
  echo "Some error in getting data.."
  rm -f $outname.gz
  exit 55
fi
cat << EOF >  $tmp.in
$outname 
$databox
EOF
  ./makegrid.bash  $tmp.in 
err=$(( $err + $? )) 
  rm -f $tmp.*
#grdmath cpc.$d1.grd cpc.$d2.grd ADD 0.5 MUL = cpc.48.$d1.grd

#
out=$outname.ps
title="${hdiff}h accumulated CPC_PRECIP  at $date UT"
filetobeplotted=$outname.grd
#call the plotting program in current env.
todate=$date
details="CPC rainfall product (NOAA) for the ${hdiff}h period ending at $date"
PLOTBOX=$PLOTBOX #just to remind you :-)
#set -x
source ./plotgrid.script
err=$(( $err + $? )) 
#set +x
$convert $outname.ps $outname.png
if [ ! -z $GMTIMAGECLIPGEOMETRY ]; then
  #we have a clipping to do 
  convert $outname.png -crop $GMTIMAGECLIPGEOMETRY $$.png
  mv -f $$.png $outname.png 
fi
rm -f .gmt* $tmp.* $outname.grd* $outname.tmp.dat
if [ ! "$PRESERVE" ]; then
  rm -f $outname.ps  $outname 
fi
mv $outname.png ./results/.
exit $err


  

